@@ -489,7 +489,7 @@ eel_string_list_find_by_function (const EelStringList *string_list,
 		return NULL;
 	}
 
-	g_return_val_if_fail (test_function != NULL, FALSE);
+	g_return_val_if_fail (test_function != NULL, NULL);
 	
 	for (node = string_list->strings; node; node = node->next) {
 		if ((* test_function) (string_list, node->data, callback_data)) {
